@@ -51,8 +51,9 @@ class TestServer(unittest.TestCase):
         params = {
             'server': {
                 'action': 'enable',
-                'conn-limit': 8000000,
+                'conn-limit': None,
                 'conn-resume': None,
+                'health-check': None,
                 'host': '192.168.2.254',
                 'name': VSERVER_NAME,
             }
@@ -84,10 +85,11 @@ class TestServer(unittest.TestCase):
         params = {
             'server': {
                 'action': 'enable',
-                'conn-limit': 8000000,
+                'conn-limit': None,
                 'conn-resume': None,
                 'host': '192.168.2.254',
                 'name': VSERVER_NAME,
+                'health-check': None,
                 'template-server': 'test-template-server'
             }
         }
@@ -135,7 +137,7 @@ class TestServer(unittest.TestCase):
         responses.add(responses.POST, AUTH_URL, json={'session_id': 'foobar'})
         json_response = {
             'server': {
-                'status': 1, 'conn_resume': 0, 'weight': 1, 'conn_limit': 8000000, 'host': '192.168.2.254',
+                'status': 1, 'conn_resume': 0, 'weight': 1, 'conn_limit': 64000000, 'host': '192.168.2.254',
                 'spoofing_cache': 0, 'port_list': [], 'gslb_external_address': '0.0.0.0', 'slow_start': 0,
                 'name': 's1', 'health_monitor': '(default)', 'extended_stats': 0, 'template': 'default',
                 'stats_data': 1, 'conn_limit_log': 0
@@ -179,8 +181,9 @@ class TestIPv6Server(unittest.TestCase):
         params = {
             'server': {
                 'action': 'enable',
-                'conn-limit': 8000000,
+                'conn-limit': None,
                 'conn-resume': None,
+                'health-check': None,
                 'server-ipv6-addr': '2001:baad:deed:bead:daab:daad:cead:100e',
                 'name': VSERVER_NAME,
             }
@@ -212,10 +215,11 @@ class TestIPv6Server(unittest.TestCase):
         params = {
             'server': {
                 'action': 'enable',
-                'conn-limit': 8000000,
+                'conn-limit': None,
                 'conn-resume': None,
                 'host': '192.168.2.254',
                 'name': VSERVER_NAME,
+                'health-check': None,
                 'template-server': 'test-template-server'
             }
         }
@@ -263,7 +267,7 @@ class TestIPv6Server(unittest.TestCase):
         responses.add(responses.POST, AUTH_URL, json={'session_id': 'foobar'})
         json_response = {
             'server': {
-                'status': 1, 'conn_resume': 0, 'weight': 1, 'conn_limit': 8000000,
+                'status': 1, 'conn_resume': 0, 'weight': 1, 'conn_limit': 64000000,
                 'server-ipv6-addr': '2001:baad:deed:bead:daab:aad:cead:100e',
                 'spoofing_cache': 0, 'port_list': [], 'gslb_external_address': '0.0.0.0', 'slow_start': 0,
                 'name': 's1', 'health_monitor': '(default)', 'extended_stats': 0, 'template': 'default',
