@@ -82,6 +82,7 @@ class VirtualPort(base.BaseV30):
         ipinip=False,
         source_nat_pool=None,
         ha_conn_mirror=None,
+        use_rcv_hop=False,
         conn_limit=None,
         virtual_port_templates=None,
         tcp_template=None,
@@ -106,7 +107,7 @@ class VirtualPort(base.BaseV30):
         if virtual_port_templates:
             virtual_port_templates = {k: v for k, v in virtual_port_templates.items() if v}
             params['port']['template-virtual-port'] = virtual_port_templates.get('template-virtual-port', None)
-            if protocol == 'http':
+            if protocol in ['http', 'https']:
                 params['port']['template-http'] = virtual_port_templates.get('template-http', None)
             else:
                 params['port']['template-tcp'] = virtual_port_templates.get('template-tcp', None)
@@ -116,6 +117,8 @@ class VirtualPort(base.BaseV30):
             params['port']['auto'] = int(autosnat)
         if ipinip:
             params['port']['ipinip'] = int(ipinip)
+        if use_rcv_hop:
+            params['port']['use-rcv-hop-for-resp'] = int(use_rcv_hop)
         if source_nat_pool and len(source_nat_pool) > 0:
             params['port']['pool'] = source_nat_pool
         if tcp_template:
@@ -175,6 +178,7 @@ class VirtualPort(base.BaseV30):
         no_dest_nat=None,
         source_nat_pool=None,
         ha_conn_mirror=None,
+        use_rcv_hop=False,
         conn_limit=None,
         virtual_port_templates=None,
         tcp_template=None,
@@ -196,6 +200,7 @@ class VirtualPort(base.BaseV30):
             no_dest_nat=no_dest_nat,
             source_nat_pool=source_nat_pool,
             ha_conn_mirror=ha_conn_mirror,
+            use_rcv_hop=use_rcv_hop,
             conn_limit=conn_limit,
             virtual_port_templates=virtual_port_templates,
             tcp_template=tcp_template,
@@ -218,6 +223,7 @@ class VirtualPort(base.BaseV30):
         no_dest_nat=None,
         source_nat_pool=None,
         ha_conn_mirror=None,
+        use_rcv_hop=False,
         conn_limit=None,
         virtual_port_templates=None,
         tcp_template=None,
@@ -245,6 +251,7 @@ class VirtualPort(base.BaseV30):
                 no_dest_nat=no_dest_nat,
                 source_nat_pool=source_nat_pool,
                 ha_conn_mirror=ha_conn_mirror,
+                use_rcv_hop=use_rcv_hop,
                 conn_limit=conn_limit,
                 virtual_port_templates=virtual_port_templates,
                 tcp_template=tcp_template,
@@ -268,6 +275,7 @@ class VirtualPort(base.BaseV30):
                 no_dest_nat=no_dest_nat,
                 source_nat_pool=source_nat_pool,
                 ha_conn_mirror=ha_conn_mirror,
+                use_rcv_hop=use_rcv_hop,
                 conn_limit=conn_limit,
                 virtual_port_templates=virtual_port_templates,
                 tcp_template=tcp_template,
